<?php

namespace App;

use Illuminate\Database\Eloquent\Model;


/**
 * App\Association
 *
 * @property int $id
 * @property string $name
 * @property string $acronym
 * @property string $street_address
 * @property string $city
 * @property string $state
 * @property string $state_abrv
 * @property string $zip
 * @property string|null $phone
 * @property string $public_email
 * @property string $contact_email
 * @property int $status
 * @property \Illuminate\Support\Carbon|null $created_at
 * @property \Illuminate\Support\Carbon|null $updated_at
 * @property-read \App\AssociationHomeInfo $association_home_info
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\AssociationSponsors[] $association_sponsors
 * @property-read int|null $association_sponsors_count
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\AssociationWebImage[] $association_web_images
 * @property-read int|null $association_web_images_count
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\AssociationWebSetupCarouselImages[] $association_web_setup_carousel_images
 * @property-read int|null $association_web_setup_carousel_images_count
 * @property-read \Illuminate\Database\Eloquent\Collection|\App\Notice[] $notices
 * @property-read int|null $notices_count
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association newModelQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association newQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association query()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereAcronym($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereCity($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereContactEmail($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereCreatedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereName($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association wherePhone($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association wherePublicEmail($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereState($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereStateAbrv($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereStatus($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereStreetAddress($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereUpdatedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Association whereZip($value)
 * @mixin \Eloquent
 */
class Association extends Model
{
    public function application_types(){
        return $this->hasMany('App\ApplicationTypes');
    }

    public function applications(){
        return $this->hasMany('App\Applications');
    }

    public function association_home_info() {
        return $this->hasOne('App\AssociationHomeInfo');
    }

    public function association_sponsors(){
        return $this->hasMany('App\AssociationSponsors');
    }

    public function association_sponsors_abouts(){
        return $this->hasMany('App\AssociationSponsorsAbouts');
    }

    public function association_web_images(){
        return $this->hasMany('App\AssociationWebImage');
    }

    public function association_web_setup_abouts(){
        return $this->hasOne('App\AssociationWebSetupAbout');
    }

    public function association_web_setup_carousel_images(){
        return $this->hasMany('App\AssociationWebSetupCarouselImages');
    }

    public function barns(){
        return $this->hasMany('App\Barn');
    }

    public function board_members() {
        return $this->hasMany('App\BoardMembers');
    }
    public function category_types(){
        return $this->hasMany('App\CategoryTypes');
    }

    public function category_events(){
        return $this->hasMany('App\CategoryEvents');
    }

    public function documents(){
        return $this->hasMany('App\Documents');
    }

    public function link_types() {
        return $this->hasMany('App\LinkTypes');
    }

    public function links(){
        return $this->hasMany('App\Links');
    }

    public function notices() {
        return $this->hasMany('App\Notice');
    }
}
