<?php

namespace App\Http\Controllers\Admin;

use App\Association;
use App\AssociationSponsors;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use DB;

class AssociationSponsorsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(!\Auth::user()->can('manage-sponsors')) {
            abort(401, "You are not authorized to make this request.");
        }

        $sponsors = AssociationSponsors::all();
        return view('sponsors.index', compact('sponsors'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!\Auth::user()->can('manage-sponsors')) {
            abort(401, "You are not authorized to make this request.");
        }

        return view('sponsors.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(!\Auth::user()->can('manage-sponsors')) {
            abort(401, "You are not authorized to make this request.");
        }

        $association_id = config('global.association_id');

        $request->validate([
            'association_id' => ['numeric', 'max:255'],
            //'sponsor_logo' => ['string', 'max:255'],
            'sponsor_name' => ['required', 'string', 'max:255'],
            'sponsor_level' => ['required', 'string', 'max:255'],
            'sponsor_website' => ['required', 'URL', 'max:255'],
            'street_address' => ['required', 'string', 'max:255'],
            'city' => ['required', 'string', 'max:255'],
            'state' => ['required', 'string', 'max:255'],
            'state_abrv' => ['required', 'string', 'max:2'],
            'zip' => ['required', 'string', 'max:255'],
            'phone' => ['required', 'string', 'max:255'],
            'street_address_2' => ['nullable', 'string', 'max:255'],
            'city_2' => ['nullable', 'string', 'max:255'],
            'state_2' => ['nullable', 'string', 'max:255'],
            'state_abrv_2' => ['nullable', 'string', 'max:2'],
            'zip_2' => ['nullable', 'string', 'max:255'],
            'phone_2' => ['nullable', 'string', 'max:255'],
            'start_date' => ['required', 'date'],
            'end_date' => ['required', 'date']
        ]);

        AssociationSponsors::create([
            'association_id' => $association_id,
            //'sponsor_logo' => $request->get('sponsor_logo'),
            'sponsor_name' => $request->get('sponsor_name'),
            'sponsor_level' => $request->get('sponsor_level'),
            'sponsor_website' => $request->get('sponsor_website'),
            'street_address' => $request->get('street_address'),
            'city' => $request->get('city'),
            'state' => $request->get('state'),
            'state_abrv' => $request->get('state_abrv'),
            'zip' => $request->get('zip'),
            'phone' => $request->get('phone'),
            'street_address_2' => $request->get('street_address_2'),
            'city_2' => $request->get('city_2'),
            'state_2' => $request->get('state_2'),
            'state_abrv_2' => $request->get('state_abrv_2'),
            'zip_2' => $request->get('zip_2'),
            'phone_2' => $request->get('phone_2'),
            'start_date' => $request->get('start_date'),
            'end_date' => $request->get('end_date'),
        ]);

        $request->session()->flash('alert-success', 'Sponsor created successfully.');
        return redirect('/admin/sponsors');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\AssociationSponsors  $associationSponsors
     * @return \Illuminate\Http\Response
     */
    public function show(AssociationSponsors $associationSponsors)
    {

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\AssociationSponsors  $associationSponsors
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!\Auth::user()->can('manage-sponsors')) {
            abort(401, "You are not authorized to make this request.");
        }

        $sponsor = AssociationSponsors::findOrFail($id);
        return view('sponsors.edit')->with('sponsor', $sponsor);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\AssociationSponsors  $associationSponsors
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $sponsor = AssociationSponsors::findOrFail($id);

        $data = \Request::all();

        $sponsor->update($data);

        $request->session()->flash('alert-success', 'Sponsor edited successfully.');
        return redirect('/admin/sponsors');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\AssociationSponsors  $associationSponsors
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request, $id)
    {
        if(!\Auth::user()->can('manage-sponsors')) {
            abort(401, "You are not authorized to make this request.");
        }

        $sponsor = AssociationSponsors::findOrFail($id);
        $sponsor ->delete();

        $request->session()->flash('alert-success', 'Sponsor deleted successfully.');
        return redirect('/admin/sponsors');
    }
}
