<?php

namespace App\Http\Controllers\Admin;

use App\Association;
use App\AssociationWebImage;
use Illuminate\Database\QueryException;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Http\Response;
use Redirect;
use Storage;

class AssociationWebImagesController extends Controller
{
    public function index()
    {
        $association_id = config('global.association_id');
        $association = Association::find($association_id);
        $association_web_images = $association->association_web_images()->paginate(10);
        return view('images.images', [
            'images' => $association_web_images
        ]);
    }

    public function show($id)
    {
        $association_id = config('global.association_id');
        $association = Association::find($association_id);

        $association_web_image = $association->association_web_images()->where('id', $id)->firstOrFail();

        return view('images.show', [
            'image' => $association_web_image
        ]);
    }

    public function create()
    {
        return view('images.create');
    }

    public function store(Request $request)
    {
        $association_id = config('global.association_id');
        request()->validate([
            'image_title' => 'required|max:80',
            'fileUpload' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);
        if ($files = $request->file('fileUpload')) {
            $destinationPath = 'images/assoc_'. $association_id .'_images/'; // upload path
            $profileImage = "assoc_" . $association_id . "_image_" . date('YmdHis') . "." . $files->getClientOriginalExtension();
            $files->move($destinationPath, $profileImage);
            $insert['association_id'] = "$association_id";
            $insert['image_title'] = "$request->image_title";
            $insert['image_hyperlink'] = "/" . $destinationPath . "$profileImage";
            $insert['created_at'] = now();
            $insert['updated_at'] = now();
        }
        $check = AssociationWebImage::insertGetId($insert);

        return Redirect::to('admin/images')
            ->with('success', 'Great! Image has been successfully uploaded.');

    }

    public function edit($id)
    {
        $association_id = config('global.association_id');
        $association = Association::find($association_id);

        $association_web_image = $association->association_web_images()->where('id', $id)->firstOrFail();

        return view('images.edit', [
            'image' => $association_web_image
        ]);
    }

    public function update(Request $request, $id)
    {
        request()->validate([
            'image_title' => 'required|max:80',
        ]);
        $update = [
            'association_id' => $request->association_id,
            'image_title' => $request->image_title,
            'image_hyperlink' => $request->image_hyperlink,
            'created_at' => $request->created_at,
            'updated_at' => now(),
        ];

        AssociationWebImage::where('id', $id)->update($update);
        return Redirect::to('admin/images')->with('success', 'The image title was updated successfully.');
    }

    public function destroy($id)
    {
        $file_to_delete = AssociationWebImage::where('id', $id)->pluck('image_hyperlink')->toArray();
        $image_record = AssociationWebImage::findOrFail($id);
        $status = 'success';
        $message = 'The image was deleted successfully.';

        try {
            $image_record->delete();
            Storage::delete($file_to_delete);
        } catch (QueryException $e)
        {
            $status = 'alert-danger';
            $message = 'This image is being used. It cannot be deleted.';
        }

        return Redirect::to('admin/images')->with($status, $message);
    }
}
