<?php

namespace App\Http\Controllers\Admin;

use App\Association;
use App\Notice;
use App\AssociationWebImage;
use App\Documents;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Redirector;
use Illuminate\Support\Facades\Redirect;

class NoticesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index()
    {
        $association_id = config('global.association_id');
        $association = Association::find($association_id);
        $notices = $association->notices()->orderBy('start_date', 'desc')->paginate(15);

        return view('notices.list', [
            'notices' => $notices,
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function create()
    {
        $association_id = config('global.association_id');
        $notice_images = AssociationWebImage::select('id', 'image_title')
            ->where('association_id', '=', $association_id)
            ->orderBy('image_title', 'asc')->get();
        $notice_brochures = Documents::select('doc_title', 'id')
            ->where('association_id', '=', $association_id)
            ->orderBy('doc_title', 'asc')->get();

        return view('notices.create', [
            'association_id' => $association_id,
            'notice_images' => $notice_images,
            'notice_brochures' => $notice_brochures,
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $request->validate([
            'association_id' => 'required',
            'start_date' => 'required|date',
            'end_date' => 'required|date',
            'notice_title' => 'required|max:60',
            'notice_title_hyperlink' => 'max:255',
            'line1_text' => 'max:60',
            'line1_hyperlink' => 'max:255',
            'line2_text' => 'max:60',
            'line2_hyperlink' => 'max:255',
            'line3_text' => 'max:60',
            'line3_hyperlink' => 'max:255',
            'line4_text' => 'max:60',
            'line4_hyperlink' => 'max:255',
            'line5_text' => 'max:60',
            'line5_hyperlink' => 'max:255',
            'line6_text' => 'max:60',
            'line6_hyperlink' => 'max:255',
        ]);

        Notice::create($request->all());

        return Redirect::to('admin/notices')->with('success', 'You have created a notice successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param Notice $notices
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function show($id)
    {

        $association_id = config('global.association_id');
        $association = Association::find($association_id);
        $notices = $association->notices()->where('id', $id)->get();

        return view('notices.show', [
            'notices' => $notices,
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Notice $notices
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function edit($id)
    {
        $association_id = config('global.association_id');
        $notice_images = AssociationWebImage::select('image_title', 'id')
            ->where('association_id', '=', $association_id)
            ->orderBy('image_title', 'asc')->get();
        $notice_brochures = Documents::select('doc_title', 'id')
            ->where('association_id', '=', $association_id)
            ->orderBy('doc_title', 'asc')->get();

        $data = Notice::where('id', '=', $id)->first();

        return view('notices.edit', [
            'data' => $data,
            'notice_images' => $notice_images,
            'notice_brochures' => $notice_brochures,
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param Notice $notices
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'association_id' => 'required',
            'start_date' => 'required|date',
            'end_date' => 'required|date',
            'notice_title' => 'required|max:60',
            'notice_title_hyperlink' => 'max:255',
            'line1_text' => 'max:60',
            'line1_hyperlink' => 'max:255',
            'line2_text' => 'max:60',
            'line2_hyperlink' => 'max:255',
            'line3_text' => 'max:60',
            'line3_hyperlink' => 'max:255',
            'line4_text' => 'max:60',
            'line4_hyperlink' => 'max:255',
            'line5_text' => 'max:60',
            'line5_hyperlink' => 'max:255',
            'line6_text' => 'max:60',
            'line6_hyperlink' => 'max:255',
        ]);

        $update = [
            'association_id' => $request->association_id,
            'notice_image' => $request->notice_image,
            'notice_brochure' => $request->notice_brochure,
            'start_date' => $request->start_date,
            'end_date' => $request->end_date,
            'notice_title' => $request->notice_title,
            'notice_title_hyperlink' => $request->notice_title_hyperlink,
            'line1_text' => $request->line1_text,
            'line1_small' => $request->line1_small,
            'line1_hyperlink' => $request->line1_hyperlink,
            'line2_text' => $request->line2_text,
            'line2_small' => $request->line2_small,
            'line2_hyperlink' => $request->line2_hyperlink,
            'line3_text' => $request->line3_text,
            'line3_small' => $request->line3_small,
            'line3_hyperlink' => $request->line3_hyperlink,
            'line4_text' => $request->line4_text,
            'line4_small' => $request->line4_small,
            'line4_hyperlink' => $request->line4_hyperlink,
            'line5_text' => $request->line5_text,
            'line5_small' => $request->line5_small,
            'line5_hyperlink' => $request->line5_hyperlink,
            'line6_text' => $request->line6_text,
            'line6_small' => $request->line6_small,
            'line6_hyperlink' => $request->line6_hyperlink,
            ];
        Notice::where('id', $id)->update($update);

        return Redirect::to('admin/notices')->with('success', 'The notice updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param Notice $notices
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        Notice::where('id', $id)->delete();

        return Redirect::to('admin/notices')->with('success', 'The Notice was deleted successfully.');
    }
}
