<?php

namespace App\Http\Controllers;

use App\CategoryTypes;
use Illuminate\Http\Request;
use App\Association;
use App\CategoryEvents;


class CategoryEventsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(!\Auth::user()->can('manage-events')) {
            abort(401, "You are not authorized to make this request.");
        }

        $events = CategoryEvents::all();
        return view('admin.events.index', compact('events'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!\Auth::user()->can('manage-events')) {
            abort(401, "You are not authorized to make this request.");
        }

        $types = CategoryTypes::all();
        return view('admin.events.create', ['types' => $types]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(!\Auth::user()->can('manage-events')) {
            abort(401, "You are not authorized to make this request.");
        }
        $validated_attrs = $request->validate([
            //'sponsor_logo' => ['string', 'max:255'],
            'category_type_id' => ['required', 'int'],
            'program_year' => ['required', 'string', 'max:4'],
            'title' => ['required', 'string', 'max:255'],
            'about_event' => ['required', 'string'],
            'event_host' => ['required', 'string', 'max:80'],
            'state_abrv' => ['required', 'string', 'max:2'],
            'state' => ['required', 'string', 'max:50'],
            'zip' => ['required', 'string', 'max:255'],
            'phone' => ['required', 'string', 'max:255'],
            'street_address' => ['string', 'max:255'],
            'start_date' => ['required', 'date'],
            'end_date' => ['required', 'date'],
            'host_email' => ['email'],
            'event_brochure' => ['int'],
            'venue' => ['required', 'string', 'max:80'],
            'city' => ['required', 'string', 'max:80'],
            'event_contact' => ['string'],
            'judge' => ['string'],
            'judge_hometown' => ['string', 'max:100'],
            'clinic_trainer' => ['string', 'max:100'],
            'volunteer_signup_hyperlink' => ['URL'],
            'web_hyperlink' => ['URL']
        ]);
        $validated_attrs['association_id'] = config('global.association_id');

        CategoryEvents::create($validated_attrs);

        $request->session()->flash('alert-success', 'Event created successfully.');
        return redirect('/admin/events');
    }


    /**
     * Show the form for editing the specified resource.
     *
     */
    public function edit($id)
    {
        if(!\Auth::user()->can('manage-events')) {
            abort(401, "You are not authorized to make this request.");
        }

        $event = CategoryEvents::findOrFail($id);
        $types = CategoryTypes::all();
        return view('admin.events.edit', ['event' => $event, 'types' => $types]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\AssociationSponsors  $associationSponsors
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(!\Auth::user()->can('manage-events')) {
            abort(401, "You are not authorized to make this request.");
        }

        $event= CategoryEvents::findOrFail($id);

        $data = \Request::all();

        $event->update($data);

        $request->session()->flash('alert-success', 'Event edited successfully.');
        return redirect('/admin/events');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\AssociationSponsors  $associationSponsors
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request, $id)
    {
        if(!\Auth::user()->can('manage-events')) {
            abort(401, "You are not authorized to make this request.");
        }

        $event = CategoryEvents::findOrFail($id);
        $event->delete();

        $request->session()->flash('alert-success', 'Event deleted successfully.');
        return redirect('/admin/events');
    }
}
