create database members_v2;

use members_v2;

create table associations
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  name char(80) NOT NULL UNIQUE,
  acronym char(12) NOT NULL,
  street_address char(100) NOT NULL,
  city char(60) NOT NULL,
  state char(50) NOT NULL,
  state_abrv char(2) NOT NULL,
  zip char(10) NOT NULL,
  phone char(15),
  status boolean default TRUE,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

create table roles
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  role_name char(25) NOT NULL UNIQUE,
  role_auth_level bigint(20) unsigned NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);


create table barns
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  barn_name char(36) NOT NULL UNIQUE,
  address char(80) NOT NULL,
  city char(30) NOT NULL,
  state char(20) NOT NULL,
  zip char(10) NOT NULL,
  phone char(10) NOT NULL,
  email varchar(100) UNIQUE NOT NULL,
  trainer_name char(120) NOT NULL, --eventually replace with linked table for multiple trainers
  barn_website TEXT,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table users
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  username char(36) NOT NULL UNIQUE,
  email varchar(100) UNIQUE NOT NULL,
  password char(255) NOT NULL,
  fname char(60) NOT NULL,
  lname char(60) NOT NULL,
  address char(80) NOT NULL,
  city char(30) NOT NULL,
  state char(20) NOT NULL,
  zip char(10) NOT NULL,
  phone char(10) NOT NULL,
  barn_id bigint(20) unsigned,
  role_id bigint(20) unsigned DEFAULT 0 NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (barn_id) REFERENCES barns(id),
  FOREIGN KEY (role_id) REFERENCES roles(id)
);


create table board_positions
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  board_position_title char(60) NOT NULL,
  association_id bigint(20) unsigned NOT NULL,
  officer BOOLEAN DEFAULT false,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table riders
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  user_id bigint(20) unsigned NOT NULL,
  fname char(60) NOT NULL,
  lname char(60) NOT NULL,
  dob DATE,
  trainer_id bigint(20) unsigned NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (user_id) REFERENCES users(id),
  FOREIGN KEY (trainer_id) REFERENCES users(id)
);

create table mhorses
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  user_id bigint(20) unsigned NOT NULL,
  hname char(60) NOT NULL,
  htype ENUM ('Horse','Pony') NOT NULL,
  ownership ENUM ('Schooling','Own','Lease') NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (user_id) REFERENCES users(id)
);

create table document_types
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  doc_type char(80) NOT NULL UNIQUE,
  board_members_only BOOLEAN DEFAULT false,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);


create table documents
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  doc_title char(80) NOT NULL,
  document_type_id bigint(20) unsigned NOT NULL,
  doc_hyperlink TEXT NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (document_type_id) REFERENCES document_types(id)
);

create table association_web_images
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  image_title char(80) NOT NULL,
  image_hyperlink TEXT NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table board_members
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  user_id bigint(20) unsigned NOT NULL,
  board_position_id bigint(20) unsigned NOT NULL,
  bm_email TEXT,
  bm_start_date DATE NOT NULL,
  bm_end_date DATE NOT NULL,
  bm_photo bigint(20) unsigned,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (user_id) REFERENCES users(id),
  FOREIGN KEY (board_position_id) REFERENCES board_positions(id),
  FOREIGN KEY (bm_photo) REFERENCES association_web_images(id)
);

create table association_home_infos
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL UNIQUE,
  favicon_ico_img bigint(20) unsigned,
  header_sub_title char(80),
  background_img bigint(20) unsigned,
  brand_logo bigint(20) unsigned,
  before_text char(40),
  tagline1 char(30),
  tagline2 char(30),
  tagline3 char(30),
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (favicon_ico_img) REFERENCES association_web_images(id),
  FOREIGN KEY (background_img) REFERENCES association_web_images(id),
  FOREIGN KEY (brand_logo) REFERENCES association_web_images(id)
);

create table association_web_setup_contact
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL UNIQUE,
  contact_page_title char(25) NOT NULL,
  contact_page_email char(100) NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table association_web_setup_about
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL UNIQUE,
  about_page_title char(25) NOT NULL,
  about_image bigint(20) unsigned NOT NULL,
  about_paragraph1 TEXT NOT NULL,
  about_paragraph2 TEXT,
  about_paragraph3 TEXT,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (about_image) REFERENCES association_web_images(id)
);

create table association_sponsors
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  sponsor_logo bigint(20) unsigned,
  sponsor_name char(80) NOT NULL,
  sponsor_level char(25) NOT NULL DEFAULT 'HUNTER',
  street_address char(100) NOT NULL,
  city char(60) NOT NULL,
  state char(50) NOT NULL,
  state_abrv char(2) NOT NULL,
  zip char(10) NOT NULL,
  phone char(15),
  street_address_2 char(100) NOT NULL,
  city_2 char(60) NOT NULL,
  state_2 char(50) NOT NULL,
  state_abrv_2 char(2) NOT NULL,
  zip_2 char(10) NOT NULL,
  phone_2 char(15),
  sponsor_website TEXT,
  start_date DATE NOT NULL, --DEFAULT CURRENT DATE gave me an error, feel free to undo this change if its only a problem on my end
  end_date DATE NOT NULL,
  sponsor_brochure bigint(20) unsigned,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (sponsor_brochure) REFERENCES documents(id),
  FOREIGN KEY (sponsor_logo) REFERENCES association_web_images(id)
);


create table association_web_setup_carousel_images
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  carousel_image bigint(20) unsigned NOT NULL,
  carousel_image_caption char(25),
  carousel_image_width int NOT NULL DEFAULT 640,
  carousel_image_height int NOT NULL DEFAULT 360,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (carousel_image) REFERENCES association_web_images(id)
);


create table notices
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  start_date DATE NOT NULL,
  end_date DATE NOT NULL,
  notice_title char(60) NOT NULL,
  notice_title_hyperlink TEXT,
  line1_text char(60),
  line1_small BOOLEAN DEFAULT false,
  line1_hyperlink TEXT,
  line2_text char(60),
  line2_small BOOLEAN DEFAULT false,
  line2_hyperlink TEXT,
  line3_text char(60),
  line3_small BOOLEAN DEFAULT false,
  line3_hyperlink TEXT,
  line4_text char(60),
  line4_small BOOLEAN DEFAULT false,
  line4_hyperlink TEXT,
  line5_text char(60),
  line5_small BOOLEAN DEFAULT false,
  line5_hyperlink TEXT,
  line6_text char(60),
  line6_small BOOLEAN DEFAULT false,
  line6_hyperlink TEXT,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table application_types
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  application_type_name char(40) NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table applications
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  application_type_id bigint(20) unsigned NOT NULL,
  program_year YEAR(4) NOT NULL DEFAULT NOW(),
  application_name char(40) NOT NULL,
  document_id bigint(20) unsigned,
  application_price char(10),
  paragraph1 TEXT NOT NULL,
  paragraph2 TEXT,
  paragraph3 TEXT,
  paragraph4 TEXT,
  paragraph5 TEXT,
  useful_link1_name char(60),
  useful_link1_hyperlink TEXT,
  useful_link2_name char(60),
  useful_link2_hyperlink TEXT,
  useful_link3_name char(60),
  useful_link3_hyperlink TEXT,
  modal_paragraph1 TEXT NOT NULL,
  modal_paragraph2 TEXT,
  modal_paragraph3 TEXT,
  modal_paragraph4 TEXT,
  modal_paragraph5 TEXT,
  modal_paragraph6 TEXT,
  modal_paragraph7 TEXT,
  modal_paragraph8 TEXT,
  modal_paragraph9 TEXT,
  modal_paragraph10 TEXT,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (application_type_id) REFERENCES application_types(id),
  FOREIGN KEY (document_id) REFERENCES documents(id)
);

create table link_types
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  type_name char(40) NOT NULL,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table links
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  link_type_id bigint(20) unsigned NOT NULL,
  link_name char(40) NOT NULL,
  hyperlink text NOT NULL,
  show_main_menu BOOLEAN DEFAULT false,
  show_menu_more BOOLEAN DEFAULT false,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id),
  FOREIGN KEY (link_type_id) REFERENCES link_types(id)
);
  
create table category_types
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  association_id bigint(20) unsigned NOT NULL,
  type_name char(40) NOT NULL,
  active BOOLEAN DEFAULT true,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (association_id) REFERENCES associations(id)
);

create table category_events
(
  id bigint(20) unsigned PRIMARY KEY auto_increment,
  category_type_id bigint(20) unsigned NOT NULL,
  title char(100) NOT NULL,
  about_event TEXT,
  start_date DATE,
  end_date DATE,
  event_host char(80),
  host_email TEXT,
  event_brochure bigint(20) unsigned,
  venue char(80),
  embedded_map TEXT,
  street_address char(100),
  city char(60),
  state char(50),
  state_abrv char(2),
  zip char(10),
  phone char(15),
  event_contact char(80),
  judge char(100),
  judge_hometown char(100),
  clinic_trainer char(100),
  volunteer_signup_hyperlink TEXT,
  more_info_hyperlink TEXT,
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  FOREIGN KEY (category_type_id) REFERENCES category_types(id),
  FOREIGN KEY (event_brochure) REFERENCES documents(id)
 
)


